@@ -1,11 +1,11 @@
 '''version'''
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 '''author'''
 __author__ = 'Zhenchao Jin'
 '''title'''
 __title__ = 'sssegmentation'
 '''description'''
-__description__ = 'SSSegmentation: An Open Source Strongly Supervised Semantic Segmentation Toolbox Based on PyTorch'
+__description__ = 'SSSegmentation: An Open Source Supervised Semantic Segmentation Toolbox Based on PyTorch'
 '''url'''
 __url__ = 'https://github.com/SegmentationBLWX/sssegmentation'
 '''email'''
