@@ -1,4 +1,5 @@
 '''initialize'''
 from .fpn import FPN
-from .base import BaseModel
+from .base import BaseSegmentor
+from .feature2pyramid import Feature2Pyramid
 from .selfattention import SelfAttentionBlock
\ No newline at end of file
