@@ -19,7 +19,7 @@ def checkdir(dirname):
 
 '''loadcheckpoints'''
 def loadcheckpoints(checkpointspath, logger_handle=None, cmd_args=None, map_to_cpu=True):
-    if logger_handle is not None and (cmd_args is None or cmd_args.local_rank == 0):
+    if (logger_handle is not None) and (cmd_args is None or cmd_args.local_rank == 0) and (int(os.environ.get('SLURM_PROCID', 0)) == 0):
         logger_handle.info('Loading checkpoints from %s' % checkpointspath)
     if map_to_cpu: checkpoints = torch.load(checkpointspath, map_location=torch.device('cpu'))
     else: checkpoints = torch.load(checkpointspath)
@@ -28,7 +28,7 @@ def loadcheckpoints(checkpointspath, logger_handle=None, cmd_args=None, map_to_c
 
 '''savecheckpoints'''
 def savecheckpoints(state_dict, savepath, logger_handle=None, cmd_args=None):
-    if logger_handle is not None and (cmd_args is None or cmd_args.local_rank == 0):
+    if (logger_handle is not None) and (cmd_args is None or cmd_args.local_rank == 0) and (int(os.environ.get('SLURM_PROCID', 0)) == 0):
         logger_handle.info('Saving state_dict in %s' % savepath)
     torch.save(state_dict, savepath)
     return True
\ No newline at end of file
